module FeynmanDiagramGenerator

using Reexport
@reexport using QEDbase
@reexport using QEDcore
@reexport using QEDprocesses

using MetagraphOptimization

include("QEDprocesses_patch.jl")

import Base.==
import QEDbase.process

export FlatMatrix

export QEDProcess, isphysical

export AbstractTreeLevelFeynmanDiagram, FeynmanVertex, FeynmanDiagram
export external_particles, virtual_particles, process, generate_DAG

export VirtualParticle, number_contributions
export contributions, in_contributions, out_contributions
export is_virtual, particle_pairs

export Forest

export plane_trees, labelled_plane_trees, feynman_diagrams

export can_interact
export QED

include("flat_matrix.jl")

include("trees/labelled_plane_trees.jl")
include("trees/trees.jl")
include("trees/iterator.jl")
include("trees/print.jl")

include("qft/qft.jl")

include("generic_process_def.jl")

include("diagrams/interface.jl")
include("diagrams/vertex.jl")
include("diagrams/diagrams.jl")
include("diagrams/iterator.jl")
include("diagrams/QED.jl")

include("metagraph_impl/compute.jl")
include("metagraph_impl/generation.jl")

end # module FeynmanDiagramGenerator
